#
# spec file for package flmsg
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flmsg
Version:        4.0.23
Release:        1.26
Summary:        NBEMS messaging system, forms manager/designer and transport front end
License:        GPL-3.0
Group:          Productivity/Hamradio/Other
URL:            http://www.w1hkj.com/
#Git-Clone:     https://git.code.sf.net/p/fldigi/flmsg
Source:         http://sourceforge.net/projects/fldigi/files/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fltk-devel
BuildRequires:  flxmlrpc-devel
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
FLMSG is a simple forms management editor for the amateur radio supported
standard message formats. Form data can be transferred between computers either
using standard internet email or via radio frequency broadcasts typically made
by an amateur radio operator on your behalf. flmsg forms can be very complex
and include embedded images and other controls that make data entry less error
to prone.

%prep
%setup -q

%build
export BUILD_DATE=`date -d@0`
export BUILD_USER=openSUSE
export BUILD_HOST=openSUSE
%configure
%make_build

%install
%make_install

%suse_update_desktop_file -i flmsg

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/flmsg
%{_datadir}/applications/flmsg.desktop
%{_datadir}/pixmaps/flmsg.xpm

%changelog
* Mon Sep  4 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.22
  * Compiler warnings: recode for newly revealed compiler warnings
  * mongoose security bug: add check for http header length < 0
  * Scheme: change default to "base" to avoid loss of checkmark
    button display on some Linux window managers
  * Add THOR-11, THOR-32, THOR-44 and THOR-56 to mode list
* Wed Jun 28 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.22
  * maintenance release
  * Expert dialog window bar: correct window bar name corruption
  * RAFAC F126: add RAFAC F126 form
  * fltk-1.4 mods
- update to version  4.0.21
  * maintenance release
  * Fix Fltk transpareny bug for flrig icon.
  * correct KNAME define
  * update for 64 bit build
- New specfile based on fldigi specflie
* Sat Jun 25 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.20
  * resurrect Navy Mars message form as MARS generic
  * require external flxmlrpc lib >= 1.0.1
* Mon Aug 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.19
  * add xmlrpc Client ID
  * update to build scripts
  * fix Warnings & Errors exposed by gcc 11.1.1
  * typo fix in HX support dialog, data-->date
- update to version 4.0.18
  * fix memory leak due to missing va_end(...)
  * Add Canadian Provinces / Counties to state/counties list on
    severe WX form pick lists
* Mon Sep 21 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.17
  * fixed seg fault on Send bug
  * fixed memory leaks
* Tue Jul 28 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.16
  * Mars Army: Fix line reformat method for case of very long
    unbroken sequence of characters such as repetitive RY's
  * custom form: add check for <body... </body> block statements
* Sun Jun 14 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.15
  * update URL for custom form download
  * reduce idle traffic between flmsg & fldigi
  * Add file DND to Edit & View buttons on Simple Dialog interface
  * mods driven by update to mxe
  * modify 'version' to include VERSION_PATCH
  * update source to compile with fltk 1.3.xx
- update to version 4.0.14
  * provide thread isolation on x86_64 OS-X
* Fri Aug  2 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.13
  * Maintenance release
  * change keep alive interval processing
  - fldigi will timeout after 500 msec
  - send flmsg_online xmlrpc method every 400 ms
- update to version 4.0.12
  * Maintenance release
* Mon Jul 29 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.11
  * Correct Olivia entries in time table to correspond with ADIF
    naming convention
  * Change expert dialog to allow resizing using -g WxH+X+Y command
    line parameter and by corner drag resize, flmsg remembers
    position and size between executions, unless the -g parameter
    is invoked.
  * Scrolling widgets do not resize. The fltk scroll widget does
    not resize internal widgets
  * Correct timing for flmsg/fldigi online keep-alive
* Thu Jun 20 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.10
  * Remove internal ARC forms
  * Add dialog with link to downloadable ARC custom forms
- update to version 4.0.9
  * fix all 64 bit compiler warnings
  * add double click timer to AutoSend button
  - ignore multiple clicks of button that occur within a 2
    second window.
  * Prepare for internationalization
  * change CHECKED and ON attributes to "Y"
* Sun Feb  3 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.8
* Thu Nov  8 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 4.0.7
- specfile cleanup
* Tue Apr 18 2017 dl8fcl@darc.de
- update to version 4.0.2
  see readme.txt
* Tue Dec 20 2016 dl8fcl@t-online.de
- update to version 4.0.1
  see readme.txt
* Sun Dec 11 2016 dl8fcl@darc.de
- update to version 4.0.0
  see readme.txt
* Sun Aug  7 2016 dl8fcl@t-online.de
- update to version 3.00.02
  see readme.txt
* Sat Jun 25 2016 dl8fcl@darc.de
- update to version 3.00.01
  text.add_tx
  * changed to text.add_tx_queue for transmit string
    xmlrpc interface to fldigi
  * change dictated by need to maintain backward compatibility
    in fldigi's add_tx method
  Repeat CONREQ
  * allow repeat CONREQ response
  - CONREQ station might have missed earlier CONACK's
  Timeout action
  * Changed timeout to disregard user setting fldigi squelch
    full open
  Documentation update
  * Changed to full dialog view of ARQ drop down.
* Thu Jun  9 2016 dl8fcl@t-online.de
- update to version 3.00.00
  update license to GPL v3.x
  Added embedded flmsg specific ARQ file transfers
  Added direct receipt of flmsg "Autosend" message transfers.
  Allow changing frame size during middle of transfer
  Update documentation to flmsg 3.0 usage
* Sat Apr 30 2016 dl8fcl@t-online.de
- update to version 2.0.17
* Mon Feb  8 2016 dl8fcl@t-online.de
- update to version 2.0.15
* Fri Jan  1 2016 dl8fcl@t-online.de
- update to version 2.0.13
* Sun Jul 26 2015 dl8fcl@darc.de
- update to version 2.0.12, Maintenance release
  Fix bug introduced by html5 addition
* Sat Jul 25 2015 dl8fcl@darc.de
- update to version 2.0.11, Maintenance release
  ICS213 template, Correct <b> ... </b> (missing /)
  Added the following html5 custom controls for custom forms
  time, date, datetime, datetime-local, week, month
  ARRL Radiogram, removed disclaimer in text output format
* Tue Apr 28 2015 dl8fcl@darc.de
- update to version 2.0.10
  requires libflxmlrpc
* Tue Mar 24 2015 dl8fcl@darc.de
- update to version 2.0.9, Maintenance release
* Mon Jan 12 2015 dl8fcl@darc.de
- update to version 2.0.7, Maintenance release
* Sun Dec 14 2014 dl8fcl@darc.de
- update to version 2.0.6, Maintenance release
* Thu Oct 16 2014 dl8fcl@darc.de
- update to version 2.0.5, Maintenance release
  * manual updated
* Tue Jul  1 2014 dl8fcl@darc.de
- update to version 2.0.4, Maintenance release
  * Add user and programmer documentation
  * Removed flmsg-doc source directory
  * Removed requirement to quote textarea data
  * Convert all textarea data cr-lf to \n character
  sequence
  * Escape all lf, and double quotes to \n, \"
  * Fixed issue of incorrectly filling in text area value
  when field should be empty.
  * Added detection of flmsg executable located in
  folder NBEMS_APPS
  - if present than NBEMS.files (.nbems) will be
    co-located
  * Linux / OS X user may elect to rename the hidden
  .nbems directory to NBEMS.files
* Mon Apr 21 2014 dl8fcl@darc.de
- update to version 2.0.3, Maintenance release
  Custom select
  * Added restore of current selection when items
    are updated.
- version 2.0.2
  ICS205 template
  * Correction to ICS205 html template
  Config/Ports
  * Changed to a unified configuration dialog
  Max size of textarea
  * Increased max size to 5000 characters.
  - web server will truncate any characters beyond the
    max size
  Case independent tags
  * Changed case independent search and replace for
    form tags.
  * Added extended string class based on std::string
  - ufind find matching string independent of case
  - ureplace replace matching string indepedent of case
  * Modified custom.cxx to use extended string class
  Custom html transfer
  * Added special transfer of html forms to/from CUSTOM
    folder.
* Tue Apr  1 2014 dl8fcl@darc.de
- update to version 2.0.1, Maintenance release
    Radiogram/IARU choices
  * Correct initialization of precedence listbox
    Custom Forms
  * added code to allow each instance of flmsg to have
    a unique web socket port assignment, max of 50
    simultaneous instances.
  * removed file contents case sensitivity of custom form
    search in the sub directory CUSTOM
* Mon Mar 31 2014 dl8fcl@darc.de
- update to version 2.0.0, Maintenance release
  * Moved versioning to 2.0 with advent of custom html
    form support.
    Radiogram
  * fix initializer for sel_hx_select
    CUSTOM Editable
  * Addition of support for editable custom html forms
    Form elements allowed:
  - <FORM> ... </FORM>
  - <INPUT
  - NAME
  - TYPE (text, password, radio, checkbox)
  - <SELECT ...>
  - <OPTION
  - <TEXTAREA ...>...</TEXTAREA>
  * Controls are all DISABLED for viewing
    Mongoose
  * Added mongoos web server to source
* Tue Mar 11 2014 dl8fcl@darc.de
- update to version 1.1.34, Maintenance release
* Tue Oct 29 2013 dl8fcl@darc.de
- update to version 1.1.33, Maintenance release
* Mon Jul  8 2013 dl8fcl@darc.de
- update to version 1.1.32, Maintenance release
* Sat May 25 2013 dl8fcl@darc.de
- update to version 1.1.31, Maintenance release
* Fri May 10 2013 dl8fcl@darc.de
- update to version 1.1.30
  improments to the NBEMS suite
* Sun Nov 18 2012 dl8fcl@darc.de
- update to version 1.1.29, Maintenance release
* Wed Oct 31 2012 dl8fcl@darc.de
- update to version 1.1.28, Maintenance release
* Tue Oct 23 2012 dl8fcl@darc.de
- update to version 1.1.27, Maintenance release
* Tue Sep 25 2012 dl8fcl@darc.de
- update to version 1.1.25, Maintenance release
* Fri Aug 10 2012 dl8fcl@darc.de
- update to version 1.1.23, Maintenance release
* Sat Jul  7 2012 dl8fcl@darc.de
- update to version 1.1.21, Maintenance release
* Sat Jun 16 2012 dl8fcl@darc.de
- update to version 1.1.20, Maintenance release
* Fri May  4 2012 dl8fcl@darc.de
- update to version 1.1.15
* Thu Jan 26 2012 dl8fcl@darc.de
- update to version 1.1.12, build with fltk-1.1.10 and fltk-1.3.0
* Tue Nov 15 2011 dl8fcl@darc.de
- update to version 1.1.10
* Wed Nov  2 2011 dl8fcl@darc.de
- update to version 1.1.9
* Wed Mar 30 2011 dl8fcl@darc.de
- update to version 1.1.6
* Tue Mar 22 2011 dl8fcl@darc.de
- update to version 1.1.5
* Wed Mar  9 2011 dl8fcl@darc.de
- update to version 1.1.3
* Thu Mar  3 2011 dl8fcl@darc.de
- update to version 1.1.2
* Sat Nov 27 2010 dl8fcl@darc.de
- update to version 1.1.1
* Mon Nov  8 2010 dl8fcl@darc.de
- update to version 1.1.0
* Sun Oct 24 2010 dl8fcl@darc.de
- update to version 1.0.6
* Wed Sep 15 2010 dl8fcl@darc.de
- update to version 1.0.5
* Thu Sep  9 2010 dl8fcl@darc.de
- update to version 1.0.4
* Fri Sep  3 2010 dl8fcl@darc.de
- update to version 1.0.2
* Tue Aug 31 2010 dl8fcl@darc.de
- import into build service
